pub struct BufferType(/* private fields */);Expand description
Types of buffer ownership/transfer supported by the stream. Multiple values can be supported by the driver.
Implementations
Sourceimpl BufferType
impl BufferType
Sourcepub const CLIENT_OWNED: BufferType
pub const CLIENT_OWNED: BufferType
The client allocates the VMO and registers it with the driver.
Sourcepub const DRIVER_OWNED: BufferType
pub const DRIVER_OWNED: BufferType
The driver allocates the VMO and passes handles to the client.
Sourcepub const INLINE: BufferType
pub const INLINE: BufferType
Data is sent inline within the FIDL message. This can be used exclusively (standalone) without allocating or registering VMOs, or mixed in-stream with packets of other buffer types.
Sourceimpl BufferType
impl BufferType
Sourcepub const fn empty() -> BufferType
pub const fn empty() -> BufferType
Get a flags value with all bits unset.
Sourcepub const fn all() -> BufferType
pub const fn all() -> BufferType
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<BufferType>
pub const fn from_bits(bits: u64) -> Option<BufferType>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> BufferType
pub const fn from_bits_truncate(bits: u64) -> BufferType
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> BufferType
pub const fn from_bits_retain(bits: u64) -> BufferType
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<BufferType>
pub fn from_name(name: &str) -> Option<BufferType>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: BufferType) -> bool
pub const fn intersects(&self, other: BufferType) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: BufferType) -> bool
pub const fn contains(&self, other: BufferType) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: BufferType)
pub fn insert(&mut self, other: BufferType)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: BufferType)
pub fn remove(&mut self, other: BufferType)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: BufferType)
pub fn toggle(&mut self, other: BufferType)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: BufferType, value: bool)
pub fn set(&mut self, other: BufferType, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: BufferType) -> BufferType
pub const fn intersection(self, other: BufferType) -> BufferType
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: BufferType) -> BufferType
pub const fn union(self, other: BufferType) -> BufferType
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: BufferType) -> BufferType
pub const fn difference(self, other: BufferType) -> BufferType
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: BufferType) -> BufferType
pub const fn symmetric_difference(self, other: BufferType) -> BufferType
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> BufferType
pub const fn complement(self) -> BufferType
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl BufferType
impl BufferType
Sourcepub const fn iter(&self) -> Iter<BufferType>
pub const fn iter(&self) -> Iter<BufferType>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<BufferType>
pub const fn iter_names(&self) -> IterNames<BufferType>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl BufferType
impl BufferType
pub fn from_bits_allow_unknown(bits: u64) -> BufferType
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u64