CodecProperties

Struct CodecProperties 

pub struct CodecProperties {
    pub is_input: Option<bool>,
    pub manufacturer: Option<String>,
    pub product: Option<String>,
    pub unique_id: Option<[u8; 16]>,
    pub plug_detect_capabilities: Option<PlugDetectCapabilities>,
    /* private fields */
}

Fields

is_input: Option<bool>

Driver type is input (true) or output (false) If not included, then the driver may be used for both input and output.

Optional.

manufacturer: Option<String>

UI string for the manufacturer name. If not included, the manufacturer is unspecified. If included, this string must be non-empty.

Optional.

product: Option<String>

UI string for the product name. If not included, the product name is unspecified. If included, this string must be non-empty.

Optional.

unique_id: Option<[u8; 16]>

Unique identifier for the codec. If not included, there is no unique id for this Codec. See unique_id.fidl for considerations about specific pre-defined values and ranges.

Optional.

plug_detect_capabilities: Option<PlugDetectCapabilities>

Plug Detect Capabilities.

Required.