pub struct DaiConnectorControlHandle { /* private fields */ }Trait Implementations
Sourceimpl Clone for DaiConnectorControlHandle
impl Clone for DaiConnectorControlHandle
Sourcefn clone(&self) -> DaiConnectorControlHandle
fn clone(&self) -> DaiConnectorControlHandle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ControlHandle for DaiConnectorControlHandle
impl ControlHandle for DaiConnectorControlHandle
Sourcefn shutdown(&self)
fn shutdown(&self)
Set the server to shutdown. The underlying channel is only closed the
next time the stream is polled.
Sourcefn shutdown_with_epitaph(&self, status: Status)
fn shutdown_with_epitaph(&self, status: Status)
Sets the server to shutdown with an epitaph. The underlying channel is
only closed the next time the stream is polled.
Sourcefn on_closed(&self) -> OnFDomainSignals
fn on_closed(&self) -> OnFDomainSignals
Returns a future that completes when the server receives the
PEER_CLOSED signal.Auto Trait Implementations
impl Freeze for DaiConnectorControlHandle
impl !RefUnwindSafe for DaiConnectorControlHandle
impl Send for DaiConnectorControlHandle
impl Sync for DaiConnectorControlHandle
impl Unpin for DaiConnectorControlHandle
impl !UnwindSafe for DaiConnectorControlHandle