pub struct HealthProxy { /* private fields */ }Implementations
Sourceimpl HealthProxy
impl HealthProxy
Sourcepub fn take_event_stream(&self) -> HealthEventStream
pub fn take_event_stream(&self) -> HealthEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_health_state(
&self,
) -> QueryResponseFut<HealthState, FDomainResourceDialect>
pub fn get_health_state( &self, ) -> QueryResponseFut<HealthState, FDomainResourceDialect>
Retrieves top level health state. A driver not responding promptly can be used as an indication of an unhealthy driver.